@@ -1,7 +1,7 @@
 /* CatalystX::CRUD::YUI custom JavaScript 
 
 # sync with .pm files
-my $VERSION = '0.011';   
+my $VERSION = '0.012';   
 
 */
 YAHOO.namespace('crud');
@@ -128,6 +128,46 @@ YAHOO.crud.init_histories = function () {
 /* utils */
 YAHOO.crud.cancel_action = function (ev) { return false }
 
+/*
+do not let ENTER submit the form.
+disable all the buttons to prevent double-clicks.
+TODO other validation
+*/
+YAHOO.crud.check_return_key = function(e) {
+    var numCharCode;
+    var ok;
+    
+    // assume the best
+    ok = true;
+
+    // get event if not passed
+    if (!e) {
+        e = window.event;
+    }
+    
+    // get character code of key pressed
+    if (e.keyCode) numCharCode = e.keyCode;
+    else if (e.which) numCharCode = e.which;
+
+    //Logger(numCharCode);
+    //Logger(e);
+    
+    if (numCharCode == 13) {
+        ok = false;
+    }
+        
+    return ok;
+}
+
+YAHOO.crud.submit_form = function(thisForm) {
+    Logger('submit_form() called');
+    //Logger(thisForm);
+    YAHOO.crud.disable_all_buttons('button');
+    
+    // for now, always
+    return true;
+}
+
 YAHOO.crud.hover_class_on_mousemove = function(id) {
     YAHOO.util.Event.addListener(id, 'mouseover', function(ev) {
     
@@ -175,6 +215,7 @@ YAHOO.crud.hover_class_on_mousemove = function(id) {
 YAHOO.crud.disable_button = function (button) {
     button.oldValue     = button.value;
     button.value        = '...in process...';
+    YAHOO.util.Dom.addClass(button, 'disabled');
 
     if (typeof button.disabled != 'undefined')
         button.disabled = true;
@@ -188,6 +229,8 @@ YAHOO.crud.disable_button = function (button) {
 
 YAHOO.crud.enable_button = function (button) {
     button.value        = button.oldValue;
+    YAHOO.util.Dom.removeClass(button, 'disabled');
+    
     if (typeof button.disabled != 'undefined')
         button.disabled = false;
     else if (button.buttonDisabled) {
@@ -336,7 +379,7 @@ YAHOO.crud.livegrid_form = function(args) {
                         'form',
                         Dom.get(formId)
                     )[0];
-                    //Logger(newForm);
+                    Logger(newForm);
                     var thisOid = tab.grid.opts.parent.oid;
                     var thisOidLabel = tab.grid.opts.parent.oidLabel;
                     var saveButton, resetButton;
@@ -376,21 +419,26 @@ YAHOO.crud.livegrid_form = function(args) {
                          
                         //Logger("set Cancel button");
                     }
-                    
-                    // hijack the save button so we don't actually leave this page.
-                    
-                    YAHOO.util.Connect.setForm(newForm);
-                    
-                    // can't seem to use Event here.                    
-                    newForm.onsubmit = function(e) { return false };
+                                                                          
+                    newForm.onsubmit = function(e) {
+                        //Logger("form submitted");
+                        //Logger(e);
+                        YAHOO.util.Event.stopEvent(e);  // so submit_form() isn't called
+                                                        // TODO call validate_form() here explicitly
+                        return false;
+                    };
                     
                     //Logger("set form");
                     
                     var respHandler = {
                       success: function(o) {
+                        // clear the selection so that the form is not re-loaded
+                        tab.grid.panel.getSelectionModel().clearSelections();
                         // reload the grid
                         tab.grid.panel.store.reload();
+                        // delete the form
                         Dom.get(formId).innerHTML = '';
+                        //Logger('submit OK');
                       },
                       failure: function(o) {
                         //YAHOO.crud.handleXHRFailure(o);
@@ -398,9 +446,13 @@ YAHOO.crud.livegrid_form = function(args) {
                       }
                     };
                     
+                    // hijack the save button so we don't actually leave this page.
                     YAHOO.util.Event.on(saveButton, 'click', function(e) {
                         var uri = newForm.action + '?cxc-fmt=json';
                         //alert("uri = " + uri);
+                        // make the form submit without leaving the page
+                        var ret = YAHOO.util.Connect.setForm(newForm);
+                        //Logger(ret);
                         YAHOO.util.Connect.asyncRequest('POST', uri, respHandler);
                     });
 
@@ -597,16 +649,28 @@ YAHOO.crud.new_livegrid = function(index) {
             opts.reader.columns
         );
         
+        // override default in order to allow for field names
+        // with . (dot) delimiter.
+        // we want to allow for response.* but no other *.*
+        bufferedReader.getJsonAccessor = function(expr) {
+            var re = /^response[\[\.]/;
+            return function(expr) {
+                try {
+                return(re.test(expr))
+                    ? new Function("obj", "return obj." + expr)
+                    : function(obj){
+                        return obj[expr];
+                    };
+                } catch(e){}
+                return Ext.emptyFn;
+            };
+        }();
+        
         this.store = new Ext.ux.grid.livegrid.Store({
             autoLoad   : opts.defer_load ? false : true,
-            /*
-            * docs claim bufferSize of 100 to 300 is good,
-            * but any bigger than 50 caused "glitches" in my testing.
-            * TODO >50 is problem likely due to how cxc detects limit
-            */
             bufferSize : 200,   // cxc does 200 max by default
             reader     : bufferedReader,
-            sortInfo   : {field: opts.sort_by, direction: opts.sort_dir },
+            sortInfo   : {field: opts.sort_by, direction: opts.sort_dir},
             url        : opts.url
         });
 
@@ -699,7 +763,7 @@ YAHOO.crud.new_livegrid = function(index) {
         'iconCls'        : 'icon-grid',
         //'plugins'        : new Ext.grid.GridFilters({filters:tab.grid.opts.filters}),
         'title'          : opts.title,
-        'height'         : 250,
+        'height'         : (opts.height || 250),
         'width'          : 'auto'
 
     };
@@ -724,8 +788,8 @@ YAHOO.crud.new_livegrid = function(index) {
 }
 
 YAHOO.crud.build_livegrid_filter_query = function(filters) {
-    Logger("build filter query");
-    Logger(filters);
+    //Logger("build filter query");
+    //Logger(filters);
     var p = {};
     for(var i=0, len=filters.length; i<len; i++) {
         var f = filters[i];
@@ -861,14 +925,26 @@ YAHOO.crud.new_livegrid_chooser = function(index) {
             tab.grid.opts.reader.opts, 
             tab.grid.opts.reader.columns
         );
+
+        // override default in order to allow for field names
+        // with . (dot) delimiter.
+        // we want to allow for response.* but no other *.*
+        bufferedReader.getJsonAccessor = function(expr) {
+            var re = /^response[\[\.]/;
+            return function(expr) {
+                try {
+                return(re.test(expr))
+                    ? new Function("obj", "return obj." + expr)
+                    : function(obj){
+                        return obj[expr];
+                    };
+                } catch(e){}
+                return Ext.emptyFn;
+            };
+        }();
         
         this.store = new Ext.ux.grid.livegrid.Store({
             autoLoad   : true,
-            /*
-            * docs claim bufferSize of 100 to 300 is good,
-            * but any bigger than 50 caused "glitches" in my testing.
-            * TODO >50 is problem likely due to how cxc detects limit
-            */
             bufferSize : 200,   // cxc does 200 max by default
             reader     : bufferedReader,
             sortInfo   : {field: tab.grid.opts.sort_by, direction: tab.grid.opts.sort_dir },
